@@ -10,6 +10,7 @@ from topicgpt_python.utils import *
 
 # Disable parallel tokenizers to avoid warnings
 os.environ["TOKENIZERS_PARALLELISM"] = "false"
+sbert = SentenceTransformer("all-MiniLM-L6-v2")
 
 
 def topic_parser(root_topics, df, verbose=False):
@@ -67,7 +68,6 @@ def correct(
     verbose=False,
 ):
     """Return documents with assigned topics based on relevance."""
-    sbert = SentenceTransformer("all-MiniLM-L6-v2")
     all_topics = "\n".join(topics_root.to_topic_list(desc=True, count=False))
 
     for i in tqdm(reprompt_idx, desc="Correcting topics"):
@@ -133,7 +133,6 @@ def correct_batch(
     verbose=False,
 ):
     """Return documents with assigned topics based on relevance."""
-    sbert = SentenceTransformer("all-MiniLM-L6-v2")
     all_topics = "\n".join(topics_root.to_topic_list(desc=True, count=False))
     prompts = []
 
@@ -190,7 +189,7 @@ def correct_topics(
     Main function to parse, correct, and save topic assignments.
 
     Parameters:
-    - api: API type (e.g., 'openai', 'vertex', 'vllm')
+    - api: API type (e.g., 'openai', 'vertex', 'vllm', 'gemini', 'azure')
     - model: Model name (e.g., 'gpt-4')
     - data_path: Path to data file
     - prompt_path: Path to prompt file
@@ -199,11 +198,11 @@ def correct_topics(
     - verbose: Print verbose output
     """
     api_client = APIClient(api=api, model=model)
-    max_tokens, temperature, top_p = 1000, 0.0, 1.0
+    max_tokens, temperature, top_p = 1000, 0.6, 0.9
     context_len = (
         128000
         if model not in ["gpt-3.5-turbo", "gpt-4"]
-        else (4096 if model == "gpt-3.5-turbo" else 8000) - 1000
+        else (4096 if model == "gpt-3.5-turbo" else 8000) - max_tokens
     )
 
     if verbose:
@@ -265,7 +264,7 @@ if __name__ == "__main__":
         "--api",
         type=str,
         required=True,
-        help="API type (e.g., 'openai', 'vertex', 'vllm')",
+        help="API type (e.g., 'openai', 'vertex', 'vllm', 'gemini', 'azure')",
     )
     parser.add_argument(
         "--model", type=str, required=True, help="Model name (e.g., 'gpt-4')"
